import { Writable } from 'stream';
export interface Options {
    /**
     * The string key for the 'channel' in the JSON object.
     *
     * By default, the channel inherits from the associated Slack app configuration.
     */
    channelKey?: string;
    /**
     * The mapping from level to color.
     *
     * @defaultValue `{ 30: '#2EB67D', 40: '#ECB22E', 50: '#E01E5A', 60: '#E01E5A' }`
     */
    colors?: Record<number | string, string>;
    /**
     * The string keys excluded from the JSON object.
     *
     * @defaultValue `{ hostname: 0, pid: 0 }`
     */
    excludedKeys?: Record<string, any>;
    /**
     * Keep sockets around so they can be used for future requests without having to reestablish a TCP connection.
     */
    keepAlive?: boolean;
    /**
     * The string key for the 'message' in the JSON object.
     *
     * @defaultValue `'msg'`
     */
    messageKey?: string;
    /**
     * The Incoming Webhook URL.
     */
    webhookUrl: string;
}
export declare const createTransport: (options: Options) => Writable;
export default createTransport;
